diff --git a/zephyr/modules/owntech_hrtim_driver/zephyr/src/hrtim_common.c b/zephyr/modules/owntech_hrtim_driver/zephyr/src/hrtim_common.c
index 40d30a96037208246a751842f196acad27178b1c..b724b249675af2b1d194c52b980afc6a465c0040 100644
--- a/zephyr/modules/owntech_hrtim_driver/zephyr/src/hrtim_common.c
+++ b/zephyr/modules/owntech_hrtim_driver/zephyr/src/hrtim_common.c
@@ -93,7 +93,7 @@ void hrtim_update_adc_trig_interleaved(uint16_t new_trig, hrtim_tu_t leg1_tu, hr
 	}
 }
 
-void hrtim_PeriodicEvent_en(hrtim_tu_t tu_src, uint32_t repetition, hrtim_callback_t callback)
+void hrtim_PeriodicEvent_configure(hrtim_tu_t tu_src, uint32_t repetition, hrtim_callback_t callback)
 {
 	/* Memorize user callback */
 	user_callback = callback;
@@ -102,7 +102,10 @@ void hrtim_PeriodicEvent_en(hrtim_tu_t tu_src, uint32_t repetition, hrtim_callba
 	 * is triggered every "repetition" number of periods.
 	 */
 	LL_HRTIM_TIM_SetRepetition(HRTIM1, tu_src, repetition-1);
+}
 
+void hrtim_PeriodicEvent_en(hrtim_tu_t tu_src)
+{
 	LL_HRTIM_EnableIT_REP(HRTIM1, tu_src);         /* Enabling the interrupt on repetition counter event*/
 
 	IRQ_CONNECT(HRTIM_IRQ_NUMBER, HRTIM_IRQ_PRIO, _hrtim_callback, NULL, HRTIM_IRQ_FLAGS);
@@ -123,6 +126,11 @@ void hrtim_PeriodicEvent_SetRep(hrtim_tu_t tu_src, uint32_t repetition)
 	LL_HRTIM_TIM_SetRepetition(HRTIM1, tu_src, repetition-1);
 }
 
+uint32_t hrtim_PeriodicEvent_GetRep(hrtim_tu_t tu_src)
+{
+	return LL_HRTIM_TIM_GetRepetition(HRTIM1, tu_src)+1;
+}
+
 void hrtim_init_current()
 {
 	hrtim_cm_init();
diff --git a/zephyr/modules/owntech_scheduling/zephyr/src/uninterruptible_synchronous_task.cpp b/zephyr/modules/owntech_scheduling/zephyr/src/uninterruptible_synchronous_task.cpp
index 58c0f1de09657aa82aeb9a138b17b303939573ae..39cb10fc21cfcdca1f8bf4a16330b0acf00f5860 100644
--- a/zephyr/modules/owntech_scheduling/zephyr/src/uninterruptible_synchronous_task.cpp
+++ b/zephyr/modules/owntech_scheduling/zephyr/src/uninterruptible_synchronous_task.cpp
@@ -124,7 +124,8 @@ void scheduling_start_uninterruptible_synchronous_task()
 		if ( (repetition == 0) || (user_periodic_task == NULL) )
 			return;
 
-		hrtim_PeriodicEvent_en(MSTR, repetition, user_periodic_task);
+		hrtim_PeriodicEvent_configure(MSTR, repetition, user_periodic_task);
+		hrtim_PeriodicEvent_en(MSTR);
 
 		uninterruptibleTaskStatus = task_status_t::running;
 	}
diff --git a/zephyr/modules/owntech_hrtim_driver/zephyr/public_api/hrtim.h b/zephyr/modules/owntech_hrtim_driver/zephyr/public_api/hrtim.h
index c459aa8b11070cfc938a0d4ee744244ed6fe9190..3075af4f038c03773048e81f31c6bc2cb06f0e4a 100644
--- a/zephyr/modules/owntech_hrtim_driver/zephyr/public_api/hrtim.h
+++ b/zephyr/modules/owntech_hrtim_driver/zephyr/public_api/hrtim.h
@@ -97,7 +97,7 @@ void hrtim_init_voltage_leg1_boost_leg2_buck_center_aligned(hrtim_tu_t leg1_tu,
 void hrtim_update_adc_trig_interleaved(uint16_t new_trig, hrtim_tu_t leg1_tu, hrtim_tu_t leg2_tu);
 
 /**
  * @brief Enable interrupt on repetition counter for the chosen timing unit
  * @param tu_src timing unit which will be the source for the ISR:
  *         @arg @ref MSTR
  *         @arg @ref TIMA
@@ -107,12 +107,26 @@ void hrtim_update_adc_trig_interleaved(uint16_t new_trig, hrtim_tu_t leg1_tu, hr
  *         @arg @ref TIME
  *         @arg @ref TIMF
  * @param repetition value between 1 and 256 for the repetition counter:
- * period of the event wrt. periods of the HRTIM.
- * E.g. when set to 10, one event will be triggered every 10 HRTIM period.
+ *        period of the event wrt. periods of the HRTIM.
+ *        E.g. when set to 10, one event will be triggered every 10 HRTIM period.
  * @param callback Pointer to a void(void) function that will be called
- * when the event is triggerred.
+ *        when the event is triggerred.
+ */
+void hrtim_PeriodicEvent_configure(hrtim_tu_t tu_src, uint32_t repetition, hrtim_callback_t callback);
+
+/**
+ * @brief Enable interrupt on repetition counter for the chosen timing unit.
+ *        The periodic event configuration must have been done previously.
+ * @param tu_src timing unit which will be the source for the ISR:
+ *         @arg @ref MSTR
+ *         @arg @ref TIMA
+ *         @arg @ref TIMB
+ *         @arg @ref TIMC
+ *         @arg @ref TIMD
+ *         @arg @ref TIME
+ *         @arg @ref TIMF
  */
-void hrtim_PeriodicEvent_en(hrtim_tu_t tu_src, uint32_t repetition, hrtim_callback_t callback);
+void hrtim_PeriodicEvent_en(hrtim_tu_t tu_src);
 
 /**
  * @brief Disable interrupt on repetition counter for the chosen timing unit
@@ -143,6 +157,21 @@ void hrtim_PeriodicEvent_dis(hrtim_tu_t tu_src);
  */
 void hrtim_PeriodicEvent_SetRep(hrtim_tu_t tu_src, uint32_t repetition);
 
+/**
+ * @brief Get the current value of the repetition counter.
+ * @param tu_src timing unit which will be the source for the ISR:
+ *         @arg @ref MSTR
+ *         @arg @ref TIMA
+ *         @arg @ref TIMB
+ *         @arg @ref TIMC
+ *         @arg @ref TIMD
+ *         @arg @ref TIME
+ *         @arg @ref TIMF
+ * @return Value between 1 and 256 for the repetition counter:
+ * period of the event wrt. periods of the HRTIM.
+ */
+uint32_t hrtim_PeriodicEvent_GetRep(hrtim_tu_t tu_src);
+
 #ifdef __cplusplus
 }
 #endif
@@ -97,7 +97,7 @@ void hrtim_init_voltage_leg1_boost_leg2_buck_center_aligned(hrtim_tu_t leg1_tu,
 
 /**
- * @brief Enable interrupt on repetition counter for the chosen timing unit
+ * @brief Configure interrupt on repetition counter for the chosen timing unit
  * @param tu_src timing unit which will be the source for the ISR:
  *         @arg @ref MSTR